from meresco.core import Observable

from lxml.etree import parse, XML, XSLT, _ElementTree

class Metadata2Mods(Observable):

    def __init__(self, xslFileList, nsMap):
        Observable.__init__(self)
        self._nsMap = nsMap
        for s in xslFileList:
            if   "picaplus2mods" in s: self._picaplusXslt = XSLT(parse(open(s)))
            elif "metadata2mods" in s: self._metadataXslt = XSLT(parse(open(s)))

    def _convert(self, xmlSource):
        mods = xmlSource.xpath("//mods:mods", namespaces=self._nsMap)
        if mods:
            mods = self._metadataXslt(xmlSource).getroot().getroottree()
        else:
            if xmlSource.getroot():
                mods = self._picaplusXslt(xmlSource)
            else: return XML("<root/>")
        return mods

    def addDocumentPart(self, identifier=None, name=None, lxmlNode=None):
        return self.add(identifier=identifier, name=name, lxmlNode=lxmlNode)

    def add(self, identifier=None, name=None, lxmlNode=None):
        """should be obsoleted in favor of addDocumentPart"""
        metadata = lxmlNode.xpath("/oai:metadata", namespaces=self._nsMap)
        if metadata: return self.all.addXml(self._convert(lxmlNode))
